<?php
namespace Handyman\Core;

/**
 * Add theme support,
 * Register image sizes,
 * Theme's text domain
 * Logon page later,
 *
 * Class Theme_Init
 * @package Handyman\Core
 */
class Theme_Init
{

    public static $instance;


    public function __construct()
    {
        self::$instance =& $this;

        // Enable to load jQuery from the Google CDN. Dont move it from here!
        add_theme_support('jquery-cdn');

        /**
         * HTML5 markup for search forms
         */
        add_theme_support('html5', array('search-form'));


        /**
         * Theme setup
         */
        add_action('after_setup_theme', array($this, 'setup'), 20);


        /**
         * Add Page presets
         */
        add_filter('layers_preset_layouts', array($this, 'tlChildPresets'), 0);

        /**
         * Add additional classes to body tag
         */
        add_filter('body_class', array($this, 'setBodyClasses'));

        /**
         * Title filter
         */
        add_filter('wp_title', array($this, 'setTitle'), 10);

        /**
         * Customize HTML tag
         */
        add_filter('language_attributes', array($this, 'setHtmlClasses'));

        /**
         * Add Theme logo at login page
         */
        add_action('login_head', array($this, 'doLoginPage'));

        // Register optional & requirted plugins
        add_action('tgmpa_register', array($this, 'registerRequiredPlugins'));

        // Add Support for Contact Form7 plugin
        add_filter('wpcf7_form_class_attr', array($this, 'addCF7FormClass'));

        // Strip junk from Generated form
        add_filter('wpcf7_form_elements', array($this, 'stripBr'));


        add_filter('layers_body_class', array($this, 'layersBodyClass'));

        // Remove some templates for parent themes
        //add_filter('theme_page_templates', [$this, 'removePageTemplates']);

        // Pages requested with AJAX in popup
        add_action('template_include', array($this, 'ajaxTemplate'), 99);

        // Remove unsupported navigation locations defined in parent theme
         add_action('admin_init', array($this, 'unregisterUnsupportedMenuLocations'));
    }



    public function layersBodyClass($classes)
    {
        return $classes;
    }



    /**
     *  Remove unsupported navigation locations defined in parent theme
     */
    public function unregisterUnsupportedMenuLocations()
    {
        //\Handyman\Extras\unregister_nav_menu('layers-secondary-left');
        //\Handyman\Extras\unregister_nav_menu('layers-secondary-right');
        \Handyman\Extras\unregister_nav_menu('layers-footer');
        //\Handyman\Extras\unregister_nav_menu('layers-primary-right');
    }




    /**
     * @param $title
     * @return mixed
     */
    public function setTitle($title)
    {
        return trim($title);
    }


    /**
     * @param $template
     * @return mixed
     */
    public function ajaxTemplate($template)
    {
        $popup = isset($_REQUEST['tl_popup']) && $_REQUEST['tl_popup'] == 1;

        if ($popup) {
            $template = 'single-ajax.php';
        }
        return $template;
    }


    /**
     * Main Theme setup
     */
    public function setup()
    {
        // Localize the theme
        load_child_theme_textdomain(TL_DOMAIN, TL_BASE_CHILD . '/languages');

        add_image_size('tl-square-small'    , 320, 320, true);
        add_image_size('tl-landscape-medium', 640, 400, true);
        add_image_size('tl-blog-landscape'  , 640, 280, true);

        register_nav_menus( array(
            LAYERS_THEME_SLUG . '-additional-primary' => __( 'Header Menu II' , 'layerswp' ),
        ) );
    }


    /**
     * Remove Custom Page templates from Parent theme
     *
     * @param $templates
     * @return mixed
     */
    public function removePageTemplates($templates)
    {
        return $templates;
    }


    /**
     * Load theme presets
     */
    public function tlChildPresets($layers_preset_layouts)
    {
        foreach ($layers_preset_layouts as $k => $v) {
            if ($k != 'blank') {
                unset($layers_preset_layouts[$k]);
            }
        }

        $img_preset_path = TL_BASE_URL_CHILD . '/assets/preset-images';

        // Color Scheme
        $_c = \Handyman\Core\Customizer::$instance;

        if($_c::opt('theme-primary-color', false)){
            $prim = $_c::opt('theme-primary-color');
            $sec  = $_c::opt('theme-secondary-color');
        }else{
            $defaults = $_c->customizerControlDefaults(array());
            $prim = $defaults['theme-primary-color'];
            $sec  = $defaults['theme-secondary-color'];
        }

        // Home
        $layers_child_presets['handyman-home-preset-id'] = array(
            'title' => __('Handyman - Homepage', TL_DOMAIN),
            'screenshot' => TL_BASE_URL_CHILD . '/assets/preset-images/handyman-homepage.jpg',
            'screenshot_type' => 'jpg',
            'json' => '{"obox-layers-builder-310":{"layers-widget-slide-4":{"design":{"layout":"layout-full-screen","advanced":{"customclass":"promo-title","customcss":".promo-title .section-title .heading span{\r\ncolor:#fff;\r\n}","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"slide_height":"550","show_slider_arrows":"on","slider_arrow_color":"","show_slider_dots":"on","animation_type":"slide","slide_time":"","focus_slide":"1","slide_ids":"190,233","slides":{"190":{"design":{"background":{"color":"#444","image":"' . $img_preset_path . '\/Hero-Image.jpg","repeat":"no-repeat","position":"center","stretch":"on"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"large","color":""},"advanced":{"customclass":""}},"title":"HOME IMPROVEMENTS","excerpt":"<p>THE BEST HANDYMAN WP THEME<\/p>","button":{"link_type":"custom","link_type_custom":"#","link_type_post":"","link_type_post_type_archive":"","link_type_taxonomy_archive":"","link_text":"CLICK HERE!<br\/><i>For our specials this month<\/i>"}},"233":{"design":{"background":{"color":"#444","image":"' . $img_preset_path . '\/testimonials-bg.jpg","repeat":"no-repeat","position":"center","stretch":"on"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"large","color":""},"advanced":{"customclass":""}},"title":"THE BEST HANDYMAN WP THEME","excerpt":"<p>The Best Handyman One Page Wordpess Theme<\/p>","button":{"link_type":"custom","link_type_custom":"#","link_type_post":"","link_type_post_type_archive":"","link_type_taxonomy_archive":"","link_text":"CLICK HERE!<br\/><i>For our specials this month<\/i>"}}}},"nav_menu-3":{"nav_menu":"17"},"layers-widget-tl_column-9":{"design":{"layout":"layout-boxed","liststyle":"list-grid","fonts":{"align":"text-left","size":"medium","color":""},"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"featured-section","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""}}},"title":"","excerpt":"","column_ids":"475,754,405,144","columns":{"144":{"design":{"background":{"image":"' . $img_preset_path . '\/transparent_bg_pattern.png","color":"","repeat":"repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":""}},"titlecolor":"","icon_pull":"on","icon_title":"ti-gift","width":"3","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"177","title":"GIFT VOUCHER","excerpt":"<p>Donec sollicitudin, eros eu tincidunt vulputate, quam erat scelerisque enim, et cursus elit nisl tincidunt neque.\u00a0<\/p>","link":"","link_text":"Order now"},"405":{"design":{"background":{"image":"' . $img_preset_path . '\/transparent_bg_pattern.png","color":"","repeat":"repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":""}},"titlecolor":"","icon_pull":"on","icon_title":"ti-medall","width":"3","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"175","title":"OUR GARANTEE","excerpt":"<p>Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium\u00a0omnis\u00a0perspiciatis.<\/p>","link":"","link_text":"Read More"},"475":{"design":{"background":{"image":"' . $img_preset_path . '\/transparent_bg_pattern.png","color":"","repeat":"repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":""}},"titlecolor":"","icon_pull":"on","icon_title":"ti-location-pin","width":"3","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"OUR LOCATION","excerpt":"<p><strong>Handyman Inc.<br><\/strong>123 Cesar Chavez St. San Francisko, CA 94110, United States<\/p>","link":"#widget-layers-widget-map-3","link_text":"Goto map view"},"754":{"design":{"background":{"image":"' . $img_preset_path . '\/transparent_bg_pattern.png","color":"","repeat":"repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":""}},"titlecolor":"","icon_pull":"on","icon_title":"ti-alarm-clock","width":"3","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"173","title":"WORKING HOURS","excerpt":"<table><tbody><tr><td><p>Monday - Friday<\/p><\/td><td>09.00 - 17.00<\/td><\/tr><tr><td>Saturday<\/td><td>09.00 - 15.00<\/td><\/tr><\/tbody><\/table>","link":"","link_text":"More Details"}}},"layers-widget-tl_column-10":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"buttons":{"buttons-size":"small","background-color":"","background-color-hover":"","text-color":"","text-color-hover":"","animation":"","border-radius":"","border-width":"0","border-color":"","border-color-hover":""},"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"welcome","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"title":"WELCOME TO HANDYMAN","excerpt":"","column_ids":"122,576","columns":{"122":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"","titlecolor":""}},"width":"6","c_padding":{"top":"50","right":"50","bottom":"50","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"First Class Craftmanship","excerpt":"<p>That\'s how we describe our bussiness.\u00a0Aliquam erat volutpat. Morbi tempus sollicitudin commodo. Vivamus fermentum tempor ipsum in pretium. Praesent sagittis elementum. Morbi pellentesque molestie iaculis.<\/p><p>[su_spacer][su_tl_spoiler title=\"WE ARE PASSIONATE\"]Cursis dignissimos perspiatis dictumst beatae aliqua consequuntur minus execitation etiam illo ultricies purus nulla faucibus repellat![\/su_tl_spoiler][su_tl_spoiler title=\"HONEST AND DEPENDABLE\"]Taciti elit scelerisque, primis sed, montes erat montes quibusdam prevident, quo antre urna preasent![\/su_tl_spoiler][su_tl_spoiler title=\"Call Us Today - 0800 123 456 - We Answer Our Phones 24\/7\"]Taciti elit scelerisque, primis sed, montes erat montes quibusdam prevident, quo antre urna preasent![\/su_tl_spoiler]<\/p><p><img alt=\"Our Certificates\" class=\"fr-fin fr-dii\" src=\"' . $img_preset_path . '\/certificate-logos.jpg\" title=\"Our Certificates\"><\/p>","link":"","link_text":""},"576":{"design":{"background":{"color":"#ffffff","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"","titlecolor":""}},"icon_title":"ti-comment-alt","width":"6","c_no_padding":"on","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"Quick Free Quote","excerpt":"<p>Fill in the form below and we will get back to you ASAP. You can also call us now on 0800 123 456. We\'re always more than happy to help.<\/p><p>[contact-form-7 id=\"42\" title=\"Quick Quote\" html_name=\"quickquote\"]<\/p>","link":"","link_text":""}}},"layers-widget-tl_services-2":{"design":{"layout":"layout-boxed","liststyle":"list-grid","fonts":{"align":"text-center","size":"medium","color":""},"background":{"image":"' . $img_preset_path . '\/services-bg.jpg","color":"#54533d","repeat":"no-repeat","position":"center","stretch":"on"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""}}},"title":"OUR SERVICES","excerpt":"<p>Nostra ridiculus tellus maecenas eleifend at, conubia sollicitudin repudiandae sit, nostrud debitis dicta. Quasi praesent porttitor tellus aliquid gravida mauris.<\/p>","column_ids":"858,70,41,18,158,406,414,720,876,958,489,816","columns":{"18":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"","icon_class":"fa fa-cube","width":"2","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"48","title":"Drywall Install\/Repair","excerpt":"","link":"","link_text":"Details"},"41":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"","icon_class":"fa fa-trello","width":"2","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"47","title":"Doors & Windows","excerpt":"","link":"","link_text":"Details"},"70":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"","icon_class":"fa fa-scissors","width":"2","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"46","title":"Carpentry","excerpt":"","link":"","link_text":"Details"},"158":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"","icon_class":"fa fa-plug","width":"2","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"49","title":"Electrician","excerpt":"","link":"","link_text":"Details"},"406":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"","icon_class":"fa fa-th","width":"2","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"50","title":"Floor Install\/Repair","excerpt":"","link":"","link_text":"Details"},"414":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"","icon_class":"fa fa-archive","width":"2","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"51","title":"Handyman Service","excerpt":"","link":"","link_text":"Details"},"489":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"","icon_class":"fa fa-tint","width":"2","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"55","title":"Plumbing","excerpt":"","link":"","link_text":"Details"},"720":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"","icon_class":"fa fa-edit","width":"2","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"52","title":"General Remodeling","excerpt":"","link":"","link_text":"Details"},"816":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"","icon_class":"fa fa-medkit","width":"2","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"56","title":"Aging in Place","excerpt":"","link":"","link_text":"Details"},"858":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"","icon_class":"fa fa-wrench","width":"2","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"45","title":"Bathroom Remodeling","excerpt":"","link":"","link_text":"Details"},"876":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"","icon_class":"fa fa-paint-brush","width":"2","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"53","title":"Painting & Staining","excerpt":"","link":"","link_text":"Details"},"958":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"","icon_class":"fa fa-gears","width":"2","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"54","title":"Maintenance","excerpt":"","link":"","link_text":"Details"}}},"layers-widget-tl_portfolio-3":{"design":{"layout":"layout-boxed","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"columns":"4","column-background-color":"","buttons":{"label":"","buttons-size":"medium","background-color":"","background-color-hover":"#ffffff","text-color":"#ffffff","text-color-hover":"'.$sec.'","animation":"","border-radius":"","border-width":"","border-color":"","border-color-hover":""},"imageratios":"image-landscape","background":{"color":"","image":"' . $img_preset_path . '\/transparent_bg_light_pattern.png","repeat":"repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"text_style":"overlay","show_filters":"on","hide_empty_filters":"on","show_media":"on","show_titles":"on","show_excerpts":"on","excerpt_length":"200","show_categories":"on","show_call_to_action":"on","title":"RECENT WORK","excerpt":"<p>Nostra ridiculus tellus maecenas eleifend at, conubia sollicitudin repudiandae sit, nostrud debitis dicta. Quasi praesent porttitor tellus aliquid gravida mauris.<\/p>","order":"{\"orderby\":\"menu_order\",\"order\":\"desc\"}","num_post":""},"layers-widget-tl_team-5":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""}}},"text_style":"overlay","link_on_title":"on","show_excerpts":"on","excerpt_length":"100","show_social_icons":"on","title":"HANDYMAN TEAM","excerpt":"Nostra ridiculus tellus meacenes eleifend at, conubia sollicitudin repodiandea sit, nostrud debitis dicta. Quasi preasesent porttitor tellus aliquid gravida mauris.","page_id":"","column_ids":"940,460,903,258","columns":{"258":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"'.$prim.'","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-gears","team_member_id":"233","title":"Matthew Owens","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"460":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"'.$prim.'","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-paint-brush","team_member_id":"235","title":"Nicholas Phillips","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"903":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"'.$prim.'","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-tint","team_member_id":"234","title":"Christopher Stevens","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"940":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"'.$prim.'","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-plug","team_member_id":"236","title":"Thomas Michael","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."}}},"layers-widget-tl_promotional-4":{"design":{"layout":"layout-boxed","fonts":{"align":"text-left","size":"medium","color":"#ffffff","excerpt-align":"text-left","excerpt-size":"medium","excerpt-color":"#ffffff"},"buttons":{"buttons-size":"medium","background-color":"'.$sec.'","background-color-hover":"","text-color":"#ffffff","text-color-hover":"","animation":"hvr-float","border-radius":"","border-width":"","border-color":"","border-color-hover":""},"background":{"color":"","image":"' . $img_preset_path . '\/kitchen-yellow1.jpg","repeat":"no-repeat","position":"center","stretch":"on","overlay":"on"},"advanced":{"customclass":"","customcss":"","padding":{"top":"0","right":"0","bottom":"40","left":"0"},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"heading":"<p><mark>Handyman<\/mark> Special Offer This Month<\/p>","excerpt":"<p><strong><mark>-20% For all cursus dignissimos<\/mark><\/strong> perspiciatis dictmust beatea aliqua qon minus etiam illo ultricies purus nulla faucibus reppesumbda for all tenetur mollis eius proident.<\/p>","page_id":"","link_label":"GET A JOB DONE","custom_link":"#layers-widget-tl_column-11","icon":"ti-medall"},"layers-widget-blogtips-2":{"design":{"fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"columns":"2","column-background-color":"","gutter":"on","background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"excerpt_length":"140","title":"TIPS FROM BLOG","excerpt":"<p>Nostra ridiculus tellus maecenas eleifend at, conubia sollicitudin repudiandae sit, nostrud debitis dicta. Quasi praesent porttitor tellus aliquid gravida mauris.<\/p>","category":"0","posts_per_page":"3","order":"{\"orderby\":\"date\",\"order\":\"desc\"}","featured_post":"32","blog_link":"109"},"layers-widget-tl_column-11":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-left","size":"medium","color":"","excerpt-color":""},"buttons":{"buttons-size":"small","background-color":"","background-color-hover":"","text-color":"","text-color-hover":"","animation":"","border-radius":"","border-width":"","border-color":"","border-color-hover":""},"background":{"color":"","image":"' . $img_preset_path . '\/testimonials-bg.jpg","repeat":"no-repeat","position":"center","stretch":"on"},"advanced":{"customclass":"testimonials-widget","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"title":"","excerpt":"","column_ids":"778,397","columns":{"778":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"","titlecolor":""}},"width":"6","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"","excerpt":"<p>[su_tl_testimonial yelp=\"http:\/\/yelp.com\/\"]<\/p>","link":"","link_text":""},"397":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"","titlecolor":""}},"width":"6","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":"20"},"c_class":"","post_item":"","title":"","excerpt":"<p>[su_tl_tweets consumerkey=\"\" consumersecret=\"\" accesstoken=\"\" accesstokensecret=\"\" cachetime=\"5\" username=\"\" tweetstoshow=\"4\"]<\/p>","link":"","link_text":""}}},"layers-widget-tl_pricetable-2":{"design":{"layout":"layout-boxed","gutter":"on","fonts":{"align":"text-center","size":"medium","color":""},"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""}}},"title":"OUR RATES","excerpt":"At vero eos et accusamus et iusto odio dignissimos ducimus qui blanditiis praesentium voluptatum deleniti atque corrupti.","link":"159","column_ids":"447,621,886","columns":{"447":{"design":{"text_colors":{"heading":"","sub_heading":"","features":"","button":"","button_hover":""},"bg_colors":{"column":"","features":"","button":"","button_hover":""}},"title":"HOME REPAIR SERVICE","sub_title":"Odd jobs","price":"129","sub_price":"99","currency":"$","period":"hour","excerpt":"<ul><li>Hang\u00a0pictures\u00a0and\u00a0mirrors<\/li><li>Assembling\u00a0flat\u00a0pack\u00a0furniture<\/li><li>Put\u00a0up\u00a0shelves<\/li><li>Install\u00a0plasma\u00a0TV,\u00a0LCD\u00a0TV<\/li><li><strong>and\u00a0more...<\/strong><\/li><\/ul>","link":"#widget-layers-widget-tl_column-5","link_text":"REQUEST A QUOTE"},"621":{"design":{"text_colors":{"heading":"","sub_heading":"","features":"","button":"","button_hover":""},"bg_colors":{"column":"","features":"","button":"","button_hover":""},"primary":"on"},"title":"INSTALLING COUNTERTOPS","sub_title":"Special this month","price":"69","sub_price":"99","currency":"$","period":"hour","excerpt":"<p>For custom wood countertops, <strong>we fabricate and install them<\/strong> utiling quality craftmanship and a variety of wood for to choose from.<\/p><p>Porro democritum est ex, ullum diceret quo no.<\/p>","link":"#widget-layers-widget-tl_column-5","link_text":"REQUEST A QUOTE"},"886":{"design":{"text_colors":{"heading":"","sub_heading":"","features":"","button":"","button_hover":""},"bg_colors":{"column":"","features":"","button":"","button_hover":""}},"title":"FLAT FEE PER JOB","sub_title":"Your Item Subtitle","price":"299","sub_price":"99","currency":"$","period":"job","excerpt":"<ul><li>TV\u00a0and\u00a0storage\u00a0unit<\/li><li>Bookcases\u00a0and\u00a0Bookshelves<\/li><li>Furniture\u00a0for\u00a0small\u00a0spaces<\/li><li>Indoor\u00a0dog\u00a0house<\/li><li><strong>and more...<\/strong><\/li><\/ul>","link":"#widget-layers-widget-tl_column-5","link_text":"REQUEST A QUOTE"}}},"layers-widget-tl_column-12":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"#ffffff"},"background":{"image":"' . $img_preset_path . '\/transparent_bg_dark_pattern.png","color":"","repeat":"repeat","position":"center"},"advanced":{"customclass":"request-handyman","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""}}},"title":"REQUEST HANDYMAN","excerpt":"<p>No obligation contact form. Let\'s talk about your \"to do\" list!<\/p>","column_ids":"757","columns":{"757":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":""}},"titlecolor":"","width":"12","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"","excerpt":"<p>[contact-form-7 id=\"43\" title=\"Request Handyman\" html_name=\"request_handyman\"]<\/p><p>[su_tl_contactinfo info1=\"Contact Us Today\" info2=\"We Answer Our Phones 24\/7\" phone=\"0800 123 456\"]<\/p>","link":"","link_text":""}}},"layers-widget-map-1":{"design":{"layout":"layout-fullwidth","fonts":{"align":"text-center","size":"medium","color":""},"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""}}},"map_height":"550","show_google_map":"on","title":"","excerpt":"","google_maps_location":"123 Cesar Chavez St. San Francisko, CA 94110, United States","google_maps_long_lat":"","address_shown":"","contact_form":""}}}'
        );

        // Home Multi
        $layers_child_presets['handyman-home-multi-preset-id'] = array(
            'title' => __('Handyman - Homepage II', TL_DOMAIN),
            'screenshot' => TL_BASE_URL_CHILD . '/assets/preset-images/handyman-homepage2.jpg',
            'screenshot_type' => 'jpg',
            'json' => '{"obox-layers-builder-922":{"layers-widget-slide-11":{"design":{"layout":"layout-full-screen","advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"slide_height":"550","show_slider_arrows":"on","slider_arrow_color":"","show_slider_dots":"on","animation_type":"slide","slide_time":"","focus_slide":"0","slide_ids":"190,233","slides":{"190":{"design":{"background":{"color":"#444","image":"' . $img_preset_path . '\/Hero-Image.jpg","repeat":"no-repeat","position":"center","stretch":"on"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"large","color":""},"advanced":{"customclass":""}},"title":"HOME IMPROVEMENTS","excerpt":"<p>The Best Handyman One Page Wordpess Theme<\/p>","link":"#","link_text":"CLICK HERE!<br\/><i>For our specials this month<\/i>"},"233":{"design":{"background":{"color":"#444","image":"' . $img_preset_path . '\/testimonials-bg.jpg","repeat":"no-repeat","position":"center","stretch":"on"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"large","color":""},"advanced":{"customclass":""}},"title":"THE BEST HANDYMAN WP THEME","excerpt":"<p>The Best Handyman One Page Wordpess Theme<\/p>","link":"#","link_text":"CLICK HERE!<br\/><i>For our specials this month<\/i>"}}},"nav_menu-14":{"nav_menu":"19"},"layers-widget-tl_column-36":{"design":{"layout":"layout-boxed","liststyle":"list-grid","fonts":{"align":"text-left","size":"medium","color":"","excerpt-color":""},"buttons":{"buttons-size":"small","background-color":"","background-color-hover":"","text-color":"","text-color-hover":"","animation":"","border-radius":"","border-width":"","border-color":"","border-color-hover":""},"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"featured-section","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":"tl-about-us"}},"title":"","excerpt":"","column_ids":"475,754,405","columns":{"405":{"design":{"background":{"color":"","image":"' . $img_preset_path . '/transparent_bg_pattern.png","repeat":"repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"","titlecolor":""}},"icon_pull":"on","icon_title":"ti-medall","width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"175","title":"OUR GARANTEE","excerpt":"<p>Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium\u00a0omnis\u00a0perspiciatis.<\/p>","link":"","link_text":"Read More"},"475":{"design":{"background":{"color":"","image":"' . $img_preset_path . '\/transparent_bg_pattern.png","repeat":"repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"","titlecolor":""}},"icon_pull":"on","icon_title":"ti-location-pin","width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"OUR LOCATION","excerpt":"<p><strong>Handyman Inc.<br><\/strong>123 Cesar Chavez St. San Francisko, CA 94110, United States<\/p>","link":"#widget-layers-widget-map-3","link_text":"Goto map view"},"754":{"design":{"background":{"color":"","image":"' . $img_preset_path . '\/transparent_bg_pattern.png","repeat":"repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"","titlecolor":""}},"icon_pull":"on","icon_title":"ti-alarm-clock","width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"173","title":"WORKING HOURS","excerpt":"<table><tbody><tr><td><p>Monday - Friday<\/p><\/td><td>09.00 - 17.00<\/td><\/tr><tr><td>Saturday<\/td><td>09.00 - 15.00<\/td><\/tr><\/tbody><\/table>","link":"","link_text":"More Details"}}},"layers-widget-tl_column-37":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"buttons":{"buttons-size":"small","background-color":"","background-color-hover":"","text-color":"","text-color-hover":"","animation":"hvr-fade","border-radius":"","border-width":"0","border-color":"","border-color-hover":""},"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"welcome","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":"tl-welcome"}},"title":"WELCOME TO HANDYMAN","excerpt":"","column_ids":"122,576","columns":{"122":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"","titlecolor":""}},"width":"6","c_padding":{"top":"50","right":"50","bottom":"50","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"First Class Craftmanship","excerpt":"<p>That\'s how we describe our bussiness.\u00a0Aliquam erat volutpat. Morbi tempus sollicitudin commodo. Vivamus fermentum tempor ipsum in pretium. Praesent sagittis elementum. Morbi pellentesque molestie iaculis.<\/p><p>[su_spacer][su_tl_spoiler title=\"WE ARE PASSIONATE\"]Cursis dignissimos perspiatis dictumst beatae aliqua consequuntur minus execitation etiam illo ultricies purus nulla faucibus repellat![\/su_tl_spoiler][su_tl_spoiler title=\"HONEST AND DEPENDABLE\"]Taciti elit scelerisque, primis sed, montes erat montes quibusdam prevident, quo antre urna preasent![\/su_tl_spoiler][su_tl_spoiler title=\"Call Us Today - 0800 123 456 - We Answer Our Phones 24\/7\"]Taciti elit scelerisque, primis sed, montes erat montes quibusdam prevident, quo antre urna preasent![\/su_tl_spoiler]<\/p><p><img alt=\"Our Certificates\" class=\"fr-fin fr-dii\" src=\"' . $img_preset_path . '\/certificate-logos.jpg\" title=\"Our Certificates\"><\/p>","link":"","link_text":""},"576":{"design":{"background":{"color":"#ffffff","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"","titlecolor":""}},"icon_title":"ti-comment-alt","width":"6","c_no_padding":"on","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"Quick Free Quote","excerpt":"<p>Fill in the form below and we will get back to you ASAP. You can also call us now on 0800 123 456. We\'re always more than happy to help.<\/p><p>[contact-form-7 id=\"42\" title=\"Quick Quote\" html_name=\"quickquote\"]<\/p>","link":"","link_text":""}}},"layers-widget-tl_column-38":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"buttons":{"buttons-size":"medium","background-color":"transparent","background-color-hover":"'.$prim.'","text-color":"'.$prim.'","text-color-hover":"#ffffff","animation":"","border-radius":"","border-width":"","border-color":"'.$prim.'","border-color-hover":""},"background":{"color":"'.$sec.'","image":"' . $img_preset_path . '\/laminate-flooring.jpg","repeat":"no-repeat","position":"center","stretch":"on","darken":"on"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"title":"OUR CORE SERVICES","excerpt":"","column_ids":"340,548,705","columns":{"340":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"' . $img_preset_path . '\/drywall-icon.png","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"medium","color":"#ffffff","titlecolor":"'.$prim.'"}},"width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"30","left":""},"c_class":"","post_item":"","title":"Home Renovations","excerpt":"<p>Ad exerci malorum vim. Percipit petentium reformidans ut nec<\/p>","link":"#","link_text":"Know More"},"548":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"' . $img_preset_path . '\/Electrician-icon.png","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"medium","color":"#ffffff","titlecolor":"'.$prim.'"}},"width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"30","left":""},"c_class":"","post_item":"","title":"Electrical services","excerpt":"<p>Ad exerci malorum vim. Percipit petentium reformidans ut nec<\/p>","link":"#","link_text":"Know more"},"705":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"' . $img_preset_path . '\/Flooring-Repair-icon.png","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"medium","color":"#ffffff","titlecolor":"'.$prim.'"}},"width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"Flooring Install\/Repair","excerpt":"<p>Ad exerci malorum vim. Percipit petentium reformidans ut nec.<\/p>","link":"#","link_text":"Know more"}}},"layers-widget-tl_portfolio-7":{"design":{"layout":"layout-fullwidth","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"columns":"4","column-background-color":"","buttons":{"label":"","buttons-size":"small","background-color":"","background-color-hover":"#ffffff","text-color":"#ffffff","text-color-hover":"'.$sec.'","animation":"hvr-bounce-to-bottom","border-radius":"","border-width":"","border-color":"","border-color-hover":""},"imageratios":"image-landscape","background":{"color":"","image":"' . $img_preset_path . '\/transparent_bg_pattern.png","repeat":"repeat","position":"center"},"advanced":{"customclass":"","customcss":".tl-portfolio-widget .section-title .heading span{ color:#fff;}","padding":{"top":"","right":"","bottom":"0","left":""},"margin":{"top":"","right":"","bottom":"0","left":""},"anchor":"tl-portfolio"}},"text_style":"overlay","hide_empty_filters":"on","show_media":"on","show_titles":"on","show_excerpts":"on","excerpt_length":"200","show_categories":"on","show_call_to_action":"on","title":"RECENT WORK","excerpt":"<p>Nostra ridiculus tellus maecenas eleifend at, conubia sollicitudin repudiandae sit, nostrud debitis dicta. Quasi praesent porttitor tellus aliquid gravida mauris.<\/p>","order":"{\"orderby\":\"menu_order\",\"order\":\"desc\"}","num_post":"4"},"layers-widget-tl_column-39":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-left","size":"medium","color":"","excerpt-color":""},"buttons":{"buttons-size":"large","background-color":"'.$prim.'","background-color-hover":"transparent","text-color":"#ffffff","text-color-hover":"'.$prim.'","animation":"hvr-float","border-radius":"","border-width":"","border-color":"'.$prim.'","border-color-hover":""},"background":{"color":"'.$sec.'","image":"' . $img_preset_path . '\/transparent_bg_dark_pattern.png","repeat":"repeat","position":"center"},"advanced":{"customclass":"tl-promo","customcss":".tl-promo .media.medium .button{ margin-top:0;}\r\n.tl-promo .media .media-body,.tl-promo .media{ overflow:visible;}","padding":{"top":"45","right":"","bottom":"30","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":"tl-promo"}},"title":"","excerpt":"","column_ids":"932,241","columns":{"932":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-right","size":"medium","color":"","titlecolor":"#ffffff"}},"width":"6","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"EXPLORE OUR RECENT WORK","excerpt":"","link":"","link_text":""},"241":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"","titlecolor":""}},"width":"6","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"-4","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"","excerpt":"","link":"#","link_text":"VIEW ALL PROJECTS"}}},"layers-widget-tl_team-9":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":"tl-team"}},"text_style":"overlay","link_on_title":"on","show_excerpts":"on","excerpt_length":"100","show_social_icons":"on","title":"HANDYMAN TEAM","excerpt":"Nostra ridiculus tellus meacenes eleifend at, conubia sollicitudin repodiandea sit, nostrud debitis dicta. Quasi preasesent porttitor tellus aliquid gravida mauris.","page_id":"","column_ids":"940,460,903,258","columns":{"258":{"design":{"background":{"color":"#e2e2e2","image":"","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"'.$prim.'","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-gears","team_member_id":"233","title":"Matthew Owens","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"460":{"design":{"background":{"color":"#e2e2e2","image":"","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"'.$prim.'","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-paint-brush","team_member_id":"235","title":"Nicholas Phillips","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"903":{"design":{"background":{"color":"#e2e2e2","image":"","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"'.$prim.'","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-tint","team_member_id":"234","title":"Christopher Stevens","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"940":{"design":{"background":{"color":"#e2e2e2","image":"","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"'.$prim.'","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-plug","team_member_id":"236","title":"Thomas Michael","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."}}},"layers-widget-slide-14":{"design":{"layout":"layout-fullwidth","advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"autoheight_slides":"on","slide_height":"550","show_slider_arrows":"on","slider_arrow_color":"","animation_type":"parallax","slide_time":"","focus_slide":"0","slide_ids":"252,37","slides":{"252":{"design":{"background":{"color":"#444","image":"' . $img_preset_path . '\/testimonials-bg.jpg","repeat":"no-repeat","position":"center","stretch":"on","darken":"on"},"featuredimage":"' . $img_preset_path . '\/Thomas-testimonial-1.png","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"medium","color":""},"advanced":{"customclass":""}},"title":"Thomas Michael","excerpt":"<p>\"By far this is the best theme on Envato Market. I have tried many of them but this one is easy to use and very flexible. I would highly recommend it to those who are looking for an easy customizable theme. Very nice work done.\"<\/p>","link":"","link_text":"See More"},"37":{"design":{"background":{"color":"#444","image":"' . $img_preset_path . '\/divan_svetilnik_polki_1680x1050.png","repeat":"no-repeat","position":"center","stretch":"on","darken":"on"},"featuredimage":"' . $img_preset_path . '\/Jerry-testimonial-2.png","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"medium","color":""},"advanced":{"customclass":""}},"title":"Jefry Paulino","excerpt":"<p>\"By far this is the best theme on Envato Market. I have tried many of them but this one is easy to use and very flexible. I would highly recommend it to those who are looking for an easy customizable theme.\"<\/p>","link":"","link_text":"See More"}}},"layers-widget-blogtips-9":{"design":{"fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"columns":"1","column-background-color":"","gutter":"on","background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"excerpt_length":"140","title":"TIPS FROM BLOG","excerpt":"Nostra ridiculus tellus maecenas eleifend at, conubia sollicitudin repudiandae sit, nostrud debitis dicta. Quasi praesent porttitor tellus aliquid gravida mauris.","category":"0","posts_per_page":"3","order":"{\"orderby\":\"date\",\"order\":\"desc\"}","featured_post":"261","blog_link":"109"},"layers-widget-tl_promotional-13":{"design":{"layout":"layout-boxed","fonts":{"align":"text-left","size":"medium","color":"#ffffff","excerpt-align":"text-left","excerpt-size":"medium","excerpt-color":"#ffffff"},"buttons":{"buttons-size":"small","background-color":"'.$sec.'","background-color-hover":"transparent","text-color":"#ffffff","text-color-hover":"'.$sec.'","animation":"hvr-float","border-radius":"","border-width":"1","border-color":"'.$sec.'","border-color-hover":"'.$sec.'"},"background":{"color":"","image":"' . $img_preset_path . '\/kitchen-yellow1.jpg","repeat":"no-repeat","position":"center","stretch":"on","overlay":"on"},"advanced":{"customclass":"","customcss":"","padding":{"top":"0","right":"0","bottom":"40","left":"0"},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":"tl-promo"}},"heading":"<p><mark>Handyman<\/mark> Special Offer This Month<\/p>","excerpt":"<p><strong><mark>-20% For all cursus dignissimos<\/mark><\/strong> perspiciatis dictmust beatea aliqua qon minus etiam illo ultricies purus nulla faucibus reppesumbda for all tenetur mollis eius proident.<\/p>","page_id":"","link_label":"GET A JOB DONE","custom_link":"#layers-widget-tl_column-11","icon":"ti-medall"}}}'
        );



        // Portfolio 1
          
        $layers_child_presets['handyman-portfolio-preset-id'] = array(
            'title' => __('Handyman - Portfolio Page', TL_DOMAIN),
            'screenshot' => TL_BASE_URL_CHILD . '/assets/preset-images/handyman-portfolio.jpg',
            'screenshot_type' => 'jpg',
            'json' => '{"obox-layers-builder-1528":{"layers-widget-tl_header-15":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"}},"title":"OUR PORTFOLIO"},"layers-widget-tl_post-17":{"design":{"layout":"layout-boxed","columns":"2","gutter":"on","shadow_length":"6","shadow_blur":"10","shadow_spread":"0","shadow_color":"#9b9b9b","liststyle":"list-grid","imageratios":"image-landscape","borders":{"top":"on","style":"solid","width":"5","color":"'.$prim.'"},"fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":"","post-align":"text-left","post-size":"medium","post-title-color":"#ffffff","post-title-color-hover":"","post-excerpt-color":"#444444","post-meta-color":"","post-meta-color-hover":""},"buttons":{"label":"Read More","align":"text-center","buttons-size":"medium","background-color":"","background-color-hover":"","text-color":"","text-color-hover":"","animation":"","border-radius":"","border-width":"","border-color":"","border-color-hover":""},"background":{"color":"","image":"","repeat":"no-repeat","position":"center","column-color":"#ffffff","header-color":"","media-color":"","body-color":"","footer-color":""},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"text_style":"overlay","link_on_title":"on","show_meta":"on","show_tax":"on","show_media":"on","excerpt_length":"100","title":"LATEST WORKS","excerpt":"<p>Nostra ridiculus tellus meacenes eleifend at, conubia sollicitudin repodiandea sit, nostrud debitis dicta.<\/p>","page_id":"","post_type":"tl_portfolio","button_label":"","header_items":"[]","media_items":"[\"title\"]","body_items":"[\"title\",\"excerpt\",\"button\"]","footer_items":"[]","posts_per_page":"2","sort_by":"","posts_include":""},"layers-widget-tl_portfolio-10":{"design":{"layout":"layout-boxed","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"columns":"4","column-background-color":"","buttons":{"label":"","buttons-size":"small","background-color":"","background-color-hover":"","text-color":"","text-color-hover":"","animation":"","border-radius":"","border-width":"","border-color":"","border-color-hover":""},"imageratios":"image-landscape","background":{"color":"","image":"' . $img_preset_path . '\/transparent_bg_pattern.png","repeat":"repeat","position":"center"},"advanced":{"customclass":"","customcss":".tl-portfolio-widget .section-title span{ color: #fff;}","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"text_style":"overlay","show_filters":"on","hide_empty_filters":"on","show_media":"on","show_titles":"on","show_excerpts":"on","excerpt_length":"200","show_categories":"on","show_call_to_action":"on","title":"COMPLETE PORTFOLIO","excerpt":"","order":"{\"orderby\":\"date\",\"order\":\"desc\"}","num_post":"-1"},"layers-widget-tl_column-65":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"buttons":{"buttons-size":"small","background-color":"","background-color-hover":"","text-color":"","text-color-hover":"","animation":"","border-radius":"","border-width":"","border-color":"","border-color-hover":""},"background":{"color":"","image":"' . $img_preset_path . '\/testimonials-bg.jpg","repeat":"no-repeat","position":"center","stretch":"on"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"title":"","excerpt":"","column_ids":"517","columns":{"517":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"large","color":"","titlecolor":"#ffffff"}},"width":"12","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"VISIT US","excerpt":"<p>[su_tl_contactinfo info1=\"Contact Us Today\" info2=\"We Answer Our Phones 24\/7\" phone=\"0800 123 456\"]<\/p>","link":"","link_text":""}}}}}');



        // Services 1

        $layers_child_presets['handyman-service-preset-id'] = array(
            'title' => __('Services Page', TL_DOMAIN),
            'screenshot' => TL_BASE_URL_CHILD . '/assets/preset-images/handyman-services.jpg',
            'screenshot_type' => 'jpg',
            'json' => '{"obox-layers-builder-267":{"layers-widget-tl_header-3":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"}},"title":"HEADER TITLE"},"layers-widget-tl_post-3":{"design":{"layout":"layout-boxed","columns":"3","gutter":"on","shadow_length":"6","shadow_blur":"10","shadow_spread":"0","shadow_color":"#9b9b9b","liststyle":"list-grid","imageratios":"image-landscape","borders":{"top":"on","style":"solid","width":"5","color":"'.$prim.'"},"fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":"","post-align":"text-center","post-size":"medium","post-title-color":"#ffffff","post-title-color-hover":"","post-excerpt-color":"#ffffff","post-meta-color":"","post-meta-color-hover":""},"buttons":{"label":"Details","align":"text-center","buttons-size":"medium","background-color":"","background-color-hover":"'.$prim.'","text-color":"","text-color-hover":"","animation":"hvr-sweep-to-right","border-radius":"","border-width":"1","border-color":"#ffffff","border-color-hover":"'.$prim.'"},"background":{"color":"","image":"","repeat":"no-repeat","position":"center","column-color":"","header-color":"","media-color":"'.$sec.'","body-color":"#f39c12","footer-color":""},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"text_style":"overlay","link_on_title":"on","show_author":"on","show_date":"on","show_meta":"on","show_tax":"on","show_media":"on","excerpt_length":"100","popup":"on","title":"OUR SERVICES","excerpt":"Nostra ridiculus tellus meacenes eleifend at, conubia sollicitudin repodiandea sit, nostrud debitis dicta. Quasi preasesent porttitor tellus aliquid gravida mauris.","page_id":"","post_type":"tl_service","button_label":"","header_items":"","media_items":"[\"title\"]","body_items":"[\"excerpt\",\"button\"]","footer_items":"[]","posts_per_page":"-1","sort_by":"","posts_include":""},"layers-widget-tl_pricetable-3":{"design":{"layout":"layout-boxed","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"title":"OUR RATES","excerpt":"At vero eos et accusamus et iusto odio dignissimos ducimus qui blanditiis praesentium voluptatum deleniti atque corrupti.","link":"","column_ids":"454,924,532","columns":{"454":{"design":{"text_colors":{"heading":"","sub_heading":"","features":"","button":"","button_hover":""},"bg_colors":{"column":"","features":"","button":"","button_hover":""}},"title":"Your Item Title","sub_title":"Your Item Subtitle","price":"99","sub_price":"99","currency":"$","period":"month","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page.","link":"#","link_text":"KNOW MORE"},"924":{"design":{"text_colors":{"heading":"","sub_heading":"","features":"","button":"","button_hover":""},"bg_colors":{"column":"","features":"","button":"","button_hover":""},"primary":"on"},"title":"Your Item Title","sub_title":"Your Item Subtitle","price":"399","sub_price":"00","currency":"$","period":"month","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page.","link":"#","link_text":"KNOW MORE"},"532":{"design":{"text_colors":{"heading":"","sub_heading":"","features":"","button":"","button_hover":""},"bg_colors":{"column":"","features":"","button":"","button_hover":""}},"title":"Your Item Title","sub_title":"Your Item Subtitle","price":"79","sub_price":"59","currency":"$","period":"hour","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page.","link":"#","link_text":"KNOW MORE"}}}}}');



        // Services 2

        $layers_child_presets['handyman-service2-preset-id'] = array(
            'title' => __('Services Page II', TL_DOMAIN),
            'screenshot' => TL_BASE_URL_CHILD . '/assets/preset-images/handyman-services2.jpg',
            'screenshot_type' => 'jpg',
            'json' => '{"obox-layers-builder-271":{"layers-widget-tl_header-5":{"hide_breadcrumbs":"on","design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"}},"title":"OUR SERVICES"},"layers-widget-tl_column-3":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"buttons":{"buttons-size":"large","background-color":"'.$prim.'","background-color-hover":"","text-color":"","text-color-hover":"#ffffff","animation":"hvr-float","border-radius":"","border-width":"","border-color":"'.$prim.'","border-color-hover":""},"background":{"color":"","image":"' . $img_preset_path . '\/transparent_bg_light_pattern.png","repeat":"repeat","position":"center"},"advanced":{"customclass":"local-promo","customcss":".local-promo .column{ margin-bottom:0 !important;}","padding":{"top":"","right":"","bottom":"0","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"title":"","excerpt":"","column_ids":"727","columns":{"727":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"' . $img_preset_path . '\/handyman.png","featuredvideo":"","imagealign":"image-left","fonts":{"align":"text-left","size":"large","color":"","titlecolor":"'.$sec.'"}},"width":"12","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"We Provide Professional Services","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page.","link":"#","link_text":"Contact Us"}}},"layers-widget-tl_services-3":{"design":{"layout":"layout-boxed","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"background":{"color":"'.$sec.'","image":"' . $img_preset_path . '\/transparent_bg_dark_pattern.png","repeat":"repeat","position":"center"},"advanced":{"customclass":"our-services","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"title":"","excerpt":"","column_ids":"558,629,512,704,910,381,38,203","columns":{"558":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"'.$prim.'","icon_class":"fa fa-pencil","width":"3","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"46","title":"Carpentry","excerpt":"","link":"#","link_text":"Details"},"629":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"'.$prim.'","icon_class":"fa fa-wrench","width":"3","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"52","title":"General Remodeling","excerpt":"","link":"#","link_text":"Details"},"512":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"'.$prim.'","icon_class":"fa fa-th","width":"3","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"50","title":"Floor Install\/Repair","excerpt":"","link":"#","link_text":"Details"},"704":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"'.$prim.'","icon_class":"fa fa-paint-brush","width":"3","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"53","title":"Painting & Staining","excerpt":"","link":"#","link_text":"Details"},"910":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"'.$prim.'","icon_class":"fa fa-plug","width":"3","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"49","title":"Electrician","excerpt":"","link":"#","link_text":"Details"},"381":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"'.$prim.'","icon_class":"fa fa-cube","width":"3","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"56","title":"Aging in Place","excerpt":"","link":"#","link_text":"Details"},"38":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"'.$prim.'","icon_class":"fa fa-scissors","width":"3","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"48","title":"Drywall Install\/Repair","excerpt":"","link":"#","link_text":"Details"},"203":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"small","color":""}},"titlecolor":"'.$prim.'","icon_class":"fa fa-trello","width":"3","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"47","title":"Doors & Windows","excerpt":"","link":"#","link_text":"Details"}}},"layers-widget-tl_pricetable-5":{"design":{"layout":"layout-boxed","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"title":"OUR RATES","excerpt":"At vero eos et accusamus et iusto odio dignissimos ducimus qui blanditiis praesentium voluptatum deleniti atque corrupti.","link":"","column_ids":"81,36,949","columns":{"81":{"design":{"text_colors":{"heading":"","sub_heading":"","features":"","button":"","button_hover":""},"bg_colors":{"column":"","features":"","button":"","button_hover":""}},"title":"Your Item Title","sub_title":"Your Item Subtitle","price":"00","sub_price":"00","currency":"$","period":"month","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page.","link":"","link_text":""},"36":{"design":{"text_colors":{"heading":"","sub_heading":"","features":"","button":"","button_hover":""},"bg_colors":{"column":"","features":"","button":"","button_hover":""},"primary":"on"},"title":"Your Item Title","sub_title":"Your Item Subtitle","price":"00","sub_price":"00","currency":"$","period":"month","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page.","link":"","link_text":""},"949":{"design":{"text_colors":{"heading":"","sub_heading":"","features":"","button":"","button_hover":""},"bg_colors":{"column":"","features":"","button":"","button_hover":""}},"title":"Your Item Title","sub_title":"Your Item Subtitle","price":"00","sub_price":"00","currency":"$","period":"month","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page.","link":"","link_text":""}}},"layers-widget-tl_column-4":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":"'.$sec.'"},"buttons":{"buttons-size":"small","background-color":"","background-color-hover":"","text-color":"","text-color-hover":"","animation":"","border-radius":"","border-width":"","border-color":"","border-color-hover":""},"background":{"color":"'.$prim.'","image":"' . $img_preset_path . '\/transparent_bg_light_pattern.png","repeat":"repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"title":"20% DISCOUNT. ONLY THIS MONTH! .","excerpt":"<p>Cat ipsum dolor sit amet, stare out the window. Purr for no reason rub face on owner but swat turds around the house for no reason rub face.<\/p>","column_ids":"798,878,768","columns":{"798":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"' . $img_preset_path . '\/Electrician-icon.png","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"medium","color":"","titlecolor":"'.$sec.'"}},"width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"Electrician","excerpt":"","link":"","link_text":""},"878":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"' . $img_preset_path . '\/Painting-Staining-icon.png","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"medium","color":"","titlecolor":"'.$sec.'"}},"width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"Indoor Painting","excerpt":"","link":"","link_text":""},"768":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"' . $img_preset_path . '\/door-window-icon.png","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"medium","color":"","titlecolor":"'.$sec.'"}},"width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"Doors and Windows","excerpt":"","link":"","link_text":""}}}}}');



        // Team
          
        $layers_child_presets['handyman-team-preset-id'] = array(
            'title' => __('Handyman - Team', TL_DOMAIN),
            'screenshot' => TL_BASE_URL_CHILD . '/assets/preset-images/handyman-team.jpg',
            'screenshot_type' => 'jpg',
            'json' => '{"obox-layers-builder-1675":{"layers-widget-tl_header-18":{"hide_breadcrumbs":"on","design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"}},"title":"HANDYMAN TEAM"},"layers-widget-tl_team-12":{"design":{"layout":"layout-fullwidth","liststyle":"list-grid","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"text_style":"overlay","link_on_title":"on","excerpt_length":"100","popup":"on","show_social_icons":"on","title":"OWNERS & SENIORS","excerpt":"","page_id":"","column_ids":"942,540,199,809","columns":{"942":{"design":{"background":{"color":"#e2e2e2","image":"","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-code-fork","team_member_id":"234","title":"Christopher Stevens","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"540":{"design":{"background":{"color":"#e2e2e2","image":"","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-key","team_member_id":"233","title":"Matthew Owens","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"199":{"design":{"background":{"color":"#e2e2e2","image":"","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-tint","team_member_id":"235","title":"Nicholas Phillips","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"809":{"design":{"background":{"color":"#e2e2e2","image":"","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-plug","team_member_id":"236","title":"Thomas Michael","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."}}},"layers-widget-tl_team-13":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"0","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"text_style":"overlay","link_on_title":"on","excerpt_length":"100","popup":"on","show_social_icons":"on","title":"HANDYMAN TEAM","excerpt":"Nostra ridiculus tellus meacenes eleifend at, conubia sollicitudin repodiandea sit, nostrud debitis dicta. Quasi preasesent porttitor tellus aliquid gravida mauris.","page_id":"","column_ids":"942,540,809,199","columns":{"942":{"design":{"background":{"color":"#e2e2e2","image":"","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-tint","team_member_id":"234","title":"Christopher Stevens","excerpt":""},"540":{"design":{"background":{"color":"#e2e2e2","image":"","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-wrench","team_member_id":"233","title":"Matthew Owens","excerpt":""},"809":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-paint-brush","team_member_id":"235","title":"Nicholas Phillips","excerpt":"<p>eee<\/p>"},"199":{"design":{"background":{"color":"#e2e2e2","image":"","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-plug","team_member_id":"236","title":"Thomas Michael","excerpt":""}}}}}');



        // Contact Page
        $layers_child_presets['handyman-contact-preset-id'] = array(
            'title' => __('Handyman - Contact Page', TL_DOMAIN),
            'screenshot' => TL_BASE_URL_CHILD . '/assets/preset-images/handyman-contact.jpg',
            'screenshot_type' => 'jpg',
            'json' => '{"obox-layers-builder-924":{"layers-widget-tl_header-9":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"}},"title":"CONTACT US"},"layers-widget-map-6":{"design":{"layout":"layout-fullwidth","fonts":{"align":"text-center","size":"medium","color":""},"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"no-infobox","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"show_google_map":"on","map_height":"400","google_maps_zoom":"14","title":"","excerpt":"","google_maps_location":"1377 McAllister St, San Francisco, CA 94115, USA","google_maps_long_lat":"","address_shown":"","contact_form":""},"layers-widget-tl_column-52":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"buttons":{"buttons-size":"small","background-color":"","background-color-hover":"","text-color":"","text-color-hover":"","animation":"","border-radius":"","border-width":"0","border-color":"","border-color-hover":""},"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"welcome","customcss":".welcome .container.list-masonry .form-inner-wrapper .column{ margin-right:1%;}\r\n.welcome .column:not(.span-12) .media .excerpt{max-width:100%;}","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"title":"","excerpt":"","column_ids":"692,382,351,694","columns":{"692":{"design":{"background":{"color":"'.$sec.'","image":"' . $img_preset_path . '/transparent_bg_dark_pattern.png","repeat":"repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-right","size":"small","color":"#ffffff","titlecolor":"'.$prim.'"}},"icon_title":"icon-ti-location-pin","width":"4","c_padding":{"top":"20","right":"20","bottom":"20","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"ADDRESS","excerpt":"<p>1377 McAllister St, San Francisco, CA 94115, USA<\/p>","link":"","link_text":""},"382":{"design":{"background":{"color":"'.$sec.'","image":"' . $img_preset_path . '\/transparent_bg_dark_pattern.png","repeat":"repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-right","size":"small","color":"#ffffff","titlecolor":"'.$prim.'"}},"icon_title":"icon-ti-tablet","width":"4","c_padding":{"top":"20","right":"20","bottom":"20","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"CALL US","excerpt":"<p>Office: <strong>0880 654 321<\/strong><br>Help Line (24\/7): <strong>0800 123 456<\/strong><\/p>","link":"","link_text":""},"351":{"design":{"background":{"color":"'.$sec.'","image":"' . $img_preset_path . '\/transparent_bg_dark_pattern.png","repeat":"repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-right","size":"small","color":"#ffffff","titlecolor":"'.$prim.'"}},"icon_title":"icon-ti-time","width":"4","c_padding":{"top":"20","right":"20","bottom":"20","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"WORKING HOURS","excerpt":"<p>Working Days: <strong>09:00h - 18:00h<\/strong><br>Saturday: <strong>10:00h-16:00h<\/strong><\/p>","link":"","link_text":""},"694":{"design":{"background":{"color":"#ffffff","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"medium","color":"","titlecolor":""}},"icon_title":"icon-ti-comment-alt","width":"12","c_no_padding":"on","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"GET IN TOUCH","excerpt":"<p>Fill in the form below and we will get back to you ASAP<\/p><p>[contact-form-7 id=\"274\" title=\"Quick Quote\"]<\/p>","link":"","link_text":""}}},"layers-widget-tl_promotional-24":{"design":{"layout":"layout-boxed","fonts":{"align":"text-left","size":"medium","color":"#ffffff","excerpt-align":"text-left","excerpt-size":"medium","excerpt-color":"#ffffff"},"buttons":{"buttons-size":"small","background-color":"","background-color-hover":"","text-color":"","text-color-hover":"","animation":"hvr-float","border-radius":"","border-width":"","border-color":"","border-color-hover":""},"background":{"color":"","image":"' . $img_preset_path . '\/kitchen-yellow1.jpg","repeat":"no-repeat","position":"center","stretch":"on","overlay":"on"},"advanced":{"customclass":"","customcss":"","padding":{"top":"0","right":"0","bottom":"40","left":"0"},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"heading":"<mark>Handyman<\/mark> Special Offer This Month","excerpt":"-20% For all cursusdignissimos perspiciatis dictmust beatea aliqua qon minus etiam illo ultricies purus nulla faucibus reppesumbda for all tenetur mollis eius proident.","page_id":"","link_label":"GET A JOB DONE","custom_link":"#","icon":"fa fa-wrench"}}}'
        );

        // About Us
        $layers_child_presets['handyman-about3-preset-id'] = array(
            'title' => __('Handyman - About # 1', TL_DOMAIN),
            'screenshot' => TL_BASE_URL_CHILD . '/assets/preset-images/handyman-about3.jpg',
            'screenshot_type' => 'jpg',
            'json' => '{"obox-layers-builder-319":{"layers-widget-slide-6":{"design":{"layout":"layout-fullwidth","advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"slide_height":"450","slider_arrow_color":"","animation_type":"slide","slide_time":"","focus_slide":"0","slide_ids":"83,833","slides":{"83":{"design":{"background":{"image":"' . $img_preset_path . '\/about-bg.jpg","color":"#444","repeat":"no-repeat","position":"center","stretch":"on","darken":"on"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"medium","color":""},"advanced":{"customclass":""}},"title":"ABOUT US","excerpt":"<p>Get the latest information on new tools, trends nad ideas for your DIY projects from Handyman experts<\/p>","link":"","link_text":"See More"},"833":{"design":{"background":{"image":"","color":"#444","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"large","color":""},"advanced":{"customclass":""}},"title":"Slider Title","excerpt":"Short Excerpt","link":"","link_text":"See More"}}},"nav_menu-3":{"nav_menu":"17"},"layers-widget-tl_column-8":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"buttons":{"buttons-size":"small","background-color":"","background-color-hover":"","text-color":"","text-color-hover":"","animation":"","border-radius":"","border-width":"","border-color":"","border-color-hover":""},"background":{"color":"'.$prim.'","image":"' . $img_preset_path . '\/transparent_bg_light_pattern.png","repeat":"repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"title":"","excerpt":"","column_ids":"428,549,263","columns":{"428":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"#ffffff","titlecolor":""}},"width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"Principles","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page.","link":"","link_text":""},"549":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"#ffffff","titlecolor":""}},"width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"Values","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page.","link":"","link_text":""},"263":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"#ffffff","titlecolor":""}},"width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"Community","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page.","link":"","link_text":""}}},"layers-widget-tl_column-9":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"background":{"image":"","color":"#ffffff","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"about-3","customcss":".about-3 .excerpt{\r\nmax-width:100% !important;\r\n}\r\n.about-3 .excerpt strong{ color:#000;}","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"title":"","excerpt":"","column_ids":"646,263","columns":{"263":{"design":{"background":{"image":"","color":"#eaeaea","repeat":"no-repeat","position":"center"},"featuredimage":"' . $img_preset_path . '\/ok-guy.jpg","featuredvideo":"","imageratios":"image-portrait","imagealign":"image-top","fonts":{"align":"text-left","size":"small","color":"#888888","titlecolor":""}},"width":"4","c_padding":{"top":"20","right":"20","bottom":"20","left":"20"},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"MR. THOMAS MICHAEL ","excerpt":"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.<\/p>","link":"","link_text":""},"646":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"#888888","titlecolor":""}},"width":"8","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"About Company","excerpt":"<p>There are many variations of passages of Lorem Ipsum available, but the majority have suffered alteration in some form, by injected humour, or randomised words which don\'t look even slightly believable.\u00a0If you are going to use a passage of Lorem Ipsum, you need to be sure there is not anything embarrassing hidden in the middle of text.<\/p><p>[su_spacer][su_tl_spoiler title=\"WE ARE PASSIONATE\"]Cursis dignissimos perspiatis dictumst beatae aliqua consequuntur minus execitation etiam illo ultricies purus nulla faucibus repellat![\/su_tl_spoiler][su_tl_spoiler title=\"HONEST AND DEPENDABLE\"]Taciti elit scelerisque, primis sed, montes erat montes quibusdam prevident, quo antre urna preasent![\/su_tl_spoiler][su_tl_spoiler title=\"Call Us Today - 0800 123 456 - We Answer Our Phones 24\/7\"]Taciti elit scelerisque, primis sed, montes erat montes quibusdam prevident, quo antre urna preasent![\/su_tl_spoiler]<\/p><p><strong>OUR CORE VALUES<\/strong><\/p><p>The standard chunk of Lorem Ipsum used since the 1500s is reproduced below for those interested. Sections 1.10.32 and 1.10.33 from \"de Finibus Bonorum et Malorum\" by Cicero are also reproduced in their exact original form, accompanied by English versions from the 1914 translation by H. Rackham.<\/p><p>Contrary to popular belief, Lorem Ipsum is not simply random text. It has roots in a piece of classical Latin literature from 45 BC, making it over 2000 years old. Richard McClintock, a Latin professor at Hampden-Sydney College in Virginia, looked up one of the more obscure Latin words, consectetur, from a Lorem Ipsum passage<\/p><p><strong>MANIFEST<\/strong><\/p><p>If you are going to use a passage of Lorem Ipsum.\u00a0The standard chunk of Lorem Ipsum used since the 1500s is reproduced below for those interested. Sections 1.10.32 and 1.10.33 from \"de Finibus Bonorum et Malorum\" by Cicero are also reproduced in their exact original form, accompanied by English versions from the 1914 translation by H. Rackham.<\/p>","link":"","link_text":""}}},"layers-widget-tl_team-4":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"text_style":"regular","link_on_title":"on","show_excerpts":"on","excerpt_length":"100","show_social_icons":"on","title":"HANDYMAN TEAM","excerpt":"Nostra ridiculus tellus meacenes eleifend at, conubia sollicitudin repodiandea sit, nostrud debitis dicta. Quasi preasesent porttitor tellus aliquid gravida mauris.","page_id":"","column_ids":"314,849,893,640","columns":{"314":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"","team_member_id":"234","title":"Christopher Stevens","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"640":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"","team_member_id":"236","title":"Thomas Michael","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"849":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"","team_member_id":"233","title":"Matthew Owens","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"893":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"","name-color-hover":"","position-color":"#cccccc"}},"width":"3","icon_color":"#ffffff","icon_class":"","team_member_id":"235","title":"Nicholas Phillips","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."}}}}}'
        );

        // About Us
        $layers_child_presets['handyman-about-preset-id'] = array(
            'title' => __('Handyman - About # 2', TL_DOMAIN),
            'screenshot' => TL_BASE_URL_CHILD . '/assets/preset-images/handyman-about.jpg',
            'screenshot_type' => 'jpg',
            'json' => '{"obox-layers-builder-11":{"layers-widget-slide-1":{"design":{"layout":"layout-fullwidth","advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"slide_height":"400","slider_arrow_color":"","animation_type":"slide","slide_time":"","focus_slide":"0","slide_ids":"353","slides":{"353":{"design":{"background":{"image":"' . $img_preset_path . '/about-bg.jpg","color":"#444","repeat":"no-repeat","position":"center","stretch":"on","darken":"on"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"medium","color":""},"advanced":{"customclass":""}},"title":"ABOUT US","excerpt":"","link":"","link_text":"See More"}}},"nav_menu-1":{"nav_menu":"17"},"layers-widget-tl_column-1":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"title":"","excerpt":"","column_ids":"672,137,283","columns":{"672":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"small","color":"#888888","titlecolor":"#000000"}},"icon_pull":"on","icon_title":"ti-ruler-pencil","width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"COMPANY HISTORY","excerpt":"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et aliqua.<\/p>","link":"","link_text":""},"137":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"small","color":"#888888","titlecolor":"#000000"}},"icon_pull":"on","icon_title":"ti-briefcase","width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"AFFILIATES & PARTNERS","excerpt":"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et aliqua.<\/p>","link":"","link_text":""},"283":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"small","color":"#888888","titlecolor":"#000000"}},"icon_pull":"on","icon_title":"ti-user","width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"LEADERSHIP","excerpt":"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et aliqua.<\/p>","link":"","link_text":""}}},"layers-widget-tl_team-1":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":"#888888"},"background":{"image":"","color":"#f5f5f5","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"text_style":"overlay","link_on_title":"on","show_excerpts":"on","excerpt_length":"100","show_social_icons":"on","title":"HANDYMAN TEAM","excerpt":"Nostra ridiculus tellus meacenes eleifend at, conubia sollicitudin repodiandea sit, nostrud debitis dicta. Quasi preasesent porttitor tellus aliquid gravida mauris.","page_id":"","column_ids":"334,175,642,586","columns":{"334":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"'.$prim.'"},"imageratios":"image-portrait","fonts":{"align":"text-center","color":"#ffffff","name-align":"text-center","name-color":"#ffffff","name-color-hover":"'.$sec.'","position-color":"#ffffff"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-tint","team_member_id":"234","title":"Christopher Stevens","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"175":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"'.$prim.'"},"imageratios":"image-portrait","fonts":{"align":"text-center","color":"#ffffff","name-align":"text-center","name-color":"#ffffff","name-color-hover":"'.$sec.'","position-color":"#ffffff"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-gears","team_member_id":"233","title":"Matthew Owens","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"642":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"'.$prim.'"},"imageratios":"image-portrait","fonts":{"align":"text-center","color":"#ffffff","name-align":"text-center","name-color":"#ffffff","name-color-hover":"'.$sec.'","position-color":"#ffffff"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-paint-brush","team_member_id":"235","title":"Nicholas Phillips","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"586":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"'.$prim.'"},"imageratios":"image-portrait","fonts":{"align":"text-center","color":"#ffffff","name-align":"text-center","name-color":"#ffffff","name-color-hover":"'.$sec.'","position-color":"#ffffff"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-plug","team_member_id":"236","title":"Thomas Michael","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."}}},"layers-widget-tl_promotional-3":{"design":{"layout":"layout-boxed","fonts":{"align":"text-center","size":"small","color":"#033668","excerpt-align":"text-center","excerpt-size":"small","excerpt-color":"#ffffff"},"buttons":{"background-color":"","text-color":"","background-color-hover":"","text-color-hover":""},"background":{"image":"http:\/\/wp.dev\/demo\/wp-content\/uploads\/2015\/09\/kitchen-yellow1.jpg","color":"","repeat":"no-repeat","position":"center","stretch":"on","overlay":"on"},"advanced":{"customclass":"","customcss":"","padding":{"top":"50","right":"","bottom":"50","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"heading":"<p>Handyman Special Offer This Month<\/p>","excerpt":"<p>-20% For all cursusdignissimos perspiciatis dictmust beatea aliqua qon minus etiam illo ultricies purus nulla faucibus reppesumbda for all tenetur mollis eius proident.<\/p><p>[su_spacer size=\"40\"]<\/p><p><a class=\"button\" href=\"#\">Get a Job Done!<\/a><\/p>","page_id":"","link_label":"","custom_link":"","icon":""}}}'
        );

        // About Us
        $layers_child_presets['handyman-about2-preset-id'] = array(
            'title' => __('Handyman - About without slider', TL_DOMAIN),
            'screenshot' => TL_BASE_URL_CHILD . '/assets/preset-images/handyman-about2.jpg',
            'screenshot_type' => 'jpg',
            'json' => '{"obox-layers-builder-311":{"layers-widget-tl_header-6":{"design":{"background":{"image":"","repeat":"no-repeat","position":"center"}},"title":"ABOUT US"},"layers-widget-tl_column-6":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"title":"","excerpt":"","column_ids":"672,137,283","columns":{"137":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"small","color":"#888888","titlecolor":"#000000"}},"icon_pull":"on","icon_title":"ti-briefcase","width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"AFFILIATES & PARTNERS","excerpt":"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et aliqua.<\/p>","link":"","link_text":""},"283":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"small","color":"#888888","titlecolor":"#000000"}},"icon_pull":"on","icon_title":"ti-user","width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"LEADERSHIP","excerpt":"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et aliqua.<\/p>","link":"","link_text":""},"672":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"small","color":"#888888","titlecolor":"#000000"}},"icon_pull":"on","icon_title":"ti-ruler-pencil","width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"COMPANY HISTORY","excerpt":"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et aliqua.<\/p>","link":"","link_text":""}}},"layers-widget-tl_team-2":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":"#888888"},"background":{"image":"","color":"#f5f5f5","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"text_style":"overlay","link_on_title":"on","show_excerpts":"on","excerpt_length":"100","show_social_icons":"on","title":"HANDYMAN TEAM","excerpt":"Nostra ridiculus tellus meacenes eleifend at, conubia sollicitudin repodiandea sit, nostrud debitis dicta. Quasi preasesent porttitor tellus aliquid gravida mauris.","page_id":"","column_ids":"334,175,642,586","columns":{"175":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"'.$prim.'"},"imageratios":"image-portrait","fonts":{"align":"text-center","color":"#ffffff","name-align":"text-center","name-color":"#ffffff","name-color-hover":"'.$sec.'","position-color":"#ffffff"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-gears","team_member_id":"233","title":"Matthew Owens","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"334":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"'.$prim.'"},"imageratios":"image-portrait","fonts":{"align":"text-center","color":"#ffffff","name-align":"text-center","name-color":"#ffffff","name-color-hover":"'.$sec.'","position-color":"#ffffff"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-tint","team_member_id":"234","title":"Christopher Stevens","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"586":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"'.$prim.'"},"imageratios":"image-portrait","fonts":{"align":"text-center","color":"#ffffff","name-align":"text-center","name-color":"#ffffff","name-color-hover":"'.$sec.'","position-color":"#ffffff"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-plug","team_member_id":"236","title":"Thomas Michael","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."},"642":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"'.$prim.'"},"imageratios":"image-portrait","fonts":{"align":"text-center","color":"#ffffff","name-align":"text-center","name-color":"#ffffff","name-color-hover":"'.$sec.'","position-color":"#ffffff"}},"width":"3","icon_color":"#ffffff","icon_class":"fa fa-paint-brush","team_member_id":"235","title":"Nicholas Phillips","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."}}},"layers-widget-tl_promotional-3":{"design":{"layout":"layout-boxed","fonts":{"align":"text-center","size":"small","color":"#033668","excerpt-align":"text-center","excerpt-size":"small","excerpt-color":"#ffffff"},"buttons":{"buttons-size":"medium","background-color":"","background-color-hover":"","text-color":"","text-color-hover":"","animation":"","border-radius":"","border-width":"","border-color":"","border-color-hover":""},"background":{"color":"","image":"' . $img_preset_path . '\/kitchen-yellow1.jpg","repeat":"no-repeat","position":"center","stretch":"on","overlay":"on"},"advanced":{"customclass":"","customcss":"","padding":{"top":"50","right":"","bottom":"50","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"heading":"<p>Handyman Special Offer This Month<\/p>","excerpt":"<p>-20% For all cursusdignissimos perspiciatis dictmust beatea aliqua qon minus etiam illo ultricies purus nulla faucibus reppesumbda for all tenetur mollis eius proident.<\/p><p>[su_spacer size=\"40\"]<\/p><p><a class=\"button\" href=\"#\">Get a Job Done!<\/a><\/p>","page_id":"","link_label":"","custom_link":"","icon":""}}}'
        );

        // About Us
        $layers_child_presets['handyman-about4-preset-id'] = array(
            'title' => __('Handyman - About # 3', TL_DOMAIN),
            'screenshot' => TL_BASE_URL_CHILD . '/assets/preset-images/handyman-about4.jpg',
            'screenshot_type' => 'jpg',
            'json' => '{"obox-layers-builder-301":{"layers-widget-slide-4":{"slide_height":"450","slider_arrow_color":"","animation_type":"slide","slide_time":"","design":{"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"focus_slide":"0","slide_ids":"353","slides":{"353":{"design":{"background":{"image":"' . $img_preset_path . '\/tools.jpg","color":"#444","repeat":"no-repeat","position":"center","stretch":"on","darken":"on"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-center","size":"medium","color":""},"advanced":{"customclass":""}},"title":"ABOUT US","excerpt":"<p>Get the latest informational on new tools, trends and ideas for your DIY projects from expert Handyman<\/p>","link":"","link_text":""}}},"nav_menu-1":{"nav_menu":"17"},"layers-widget-tl_column-5":{"design":{"layout":"layout-boxed","liststyle":"list-grid","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"buttons":{"buttons-size":"medium","background-color":"","background-color-hover":"","text-color":"","text-color-hover":"","animation":"hvr-float","border-radius":"","border-width":"","border-color":"","border-color-hover":"'.$sec.'"},"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"about-features","customcss":".about-features p strong {color: #222527;}\r\n.about-features .button{ float:right;\r\ncolor:#fff;\r\nborder-color:#fff;\r\n}","padding":{"top":"90","right":"","bottom":"80","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":"#"}},"title":"","excerpt":"","column_ids":"644,757,344","columns":{"644":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"#888888","titlecolor":""}},"width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"Company History","excerpt":"<p><strong>Handyman Ltd<\/strong> is an established <strong>1988 <\/strong>consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et voluptate dolore magna aliqua. <\/p><p>Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident.<\/p>","link":"","link_text":""},"757":{"design":{"background":{"color":"","image":"","repeat":"no-repeat","position":"center"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"#888888","titlecolor":""}},"width":"4","c_padding":{"top":"","right":"","bottom":"","left":""},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":"\u00a0","excerpt":"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. <\/p><p>Sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.<strong>\u00a0Ut enim ad minim veniam, quis nostrud exercitation ullamco. <\/strong><\/p>","link":"","link_text":""},"344":{"design":{"background":{"color":"'.$prim.'","image":"' . $img_preset_path . '\/brochure.png","repeat":"no-repeat","position":"center","stretch":"on"},"featuredimage":"","featuredvideo":"","imagealign":"image-top","fonts":{"align":"text-left","size":"medium","color":"","titlecolor":"#ffffff"}},"width":"4","c_padding":{"top":"10","right":"10","bottom":"30","left":"10"},"c_margin":{"top":"","right":"","bottom":"","left":""},"c_class":"","post_item":"","title":" Download The Handyman Brochure","excerpt":"","link":"#","link_text":"DOWNLOAD"}}},"layers-widget-tl_promotional-1":{"design":{"layout":"layout-boxed","fonts":{"align":"text-center","size":"medium","color":"#ffffff","excerpt-align":"text-center","excerpt-size":"large","excerpt-color":"'.$sec.'"},"buttons":{"background-color":"'.$sec.'","text-color":"#ffffff","background-color-hover":"#002a51","text-color-hover":""},"background":{"image":"' . $img_preset_path . '\/kitchen-yellow1.jpg","color":"","repeat":"no-repeat","position":"center","stretch":"on","overlay":"on"},"advanced":{"customclass":"","customcss":"","padding":{"top":"50","right":"","bottom":"50","left":""},"margin":{"top":"","right":"","bottom":"","left":""}}},"heading":"<p><mark>Handyman<\/mark> Special Offer This Month<\/p>","excerpt":"<p><mark>-20 % For all cursus dignissimos perspiciatis<\/mark> dictumst beatae aliqua consequuntur minus etiam illo ultricies .<\/p>","page_id":"","link_label":"GET A JOB DONE","custom_link":"","icon":"ti-none"},"layers-widget-tl_team-1":{"design":{"layout":"layout-boxed","liststyle":"list-masonry","gutter":"on","fonts":{"align":"text-center","size":"medium","color":"","excerpt-color":""},"background":{"image":"","color":"","repeat":"no-repeat","position":"center"},"advanced":{"customclass":"","customcss":"","padding":{"top":"","right":"","bottom":"","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"text_style":"overlay","link_on_title":"on","show_excerpts":"on","excerpt_length":"100","show_social_icons":"on","title":"MAIN TEAM","excerpt":"<p>Nostra ridiculus tellus meacenes eleifend at, conubia sollicitudin repodiandea sit, nostrud debitis dicta. Quasi preasesent porttitor tellus aliquid gravida mauris.<\/p>","page_id":"","column_ids":"663,865,11","columns":{"11":{"design":{"background":{"image":"","color":"","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"#222527","name-color-hover":"'.$sec.'","position-color":"#888888"}},"width":"4","icon_color":"#ffffff","icon_class":"fa fa-inbox","team_member_id":"236","title":"Thomas Michael","excerpt":"<p>Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page.<\/p>"},"663":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"#222527","name-color-hover":"'.$sec.'","position-color":"#888888"}},"width":"4","icon_color":"#ffffff","icon_class":"fa fa-tint","team_member_id":"234","title":"Christopher Stevens","excerpt":"<p>Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page.<\/p>"},"865":{"design":{"background":{"image":"","color":"#e2e2e2","repeat":"no-repeat","position":"center","color-meta":"#ffffff"},"imageratios":"image-square","fonts":{"align":"text-center","color":"","name-align":"text-center","name-color":"#222527","name-color-hover":"'.$sec.'","position-color":"#888888"}},"width":"4","icon_color":"#ffffff","icon_class":"fa fa-key","team_member_id":"235","title":"Nicholas Phillips","excerpt":"Give us a brief description of the service that you are promoting. Try keep it short so that it is easy for people to scan your page."}}},"layers-widget-tl_promotional-2":{"design":{"layout":"layout-boxed","fonts":{"align":"text-left","size":"medium","color":"'.$sec.'","excerpt-align":"text-left","excerpt-size":"medium","excerpt-color":"#ffffff"},"buttons":{"buttons-size":"medium","background-color":"'.$sec.'","background-color-hover":"","text-color":"#ffffff","text-color-hover":"#ffffff","animation":"hvr-float","border-radius":"","border-width":"","border-color":"","border-color-hover":""},"background":{"color":"","image":"' . $img_preset_path . '\/kitchen-yellow1.jpg","repeat":"no-repeat","position":"center","stretch":"on","overlay":"on"},"advanced":{"customclass":"","customcss":"","padding":{"top":"50","right":"","bottom":"50","left":""},"margin":{"top":"","right":"","bottom":"","left":""},"anchor":""}},"heading":"<p>Handyman Special Offer This Month<\/p>","excerpt":"-20% For all cursusdignissimos perspiciatis dictmust beatea aliqua qon minus etiam illo ultricies purus nulla faucibus reppesumbda for all tenetur mollis eius proident.","page_id":"","link_label":"GET A JOB DONE","custom_link":"#","icon":"ti-tag"}}}'
        );

        return array_merge($layers_child_presets, $layers_preset_layouts);
    }


    /**
     * Add classes to a body tag
     *
     * @param $classes
     * @return array
     */
    public function setBodyClasses($classes)
    {
        global $tl_glob_mobile, $post;
        $classes = array_merge($classes, $tl_glob_mobile->detected());

        if (\Handyman\Extras\is_not_layers_page() || \Handyman\Extras\is_404_or_search()) {
            $classes[] = 'inner-page';
        }

        if(is_admin_bar_showing()){
            $classes[] = 'has-admin-bar';
        }
        return $classes;
    }


    /**
     * @param $classes_str
     * @return string
     */
    public function setHtmlClasses($classes_str)
    {
        global $tl_glob_mobile;
        $classes_str = $classes_str . ' class="' . implode(' ', $tl_glob_mobile->detected()) . '"';
        return $classes_str;
    }

    /**
     * Add Themes logo to a login form
     */
    public function doLoginPage()
    {
        $css  = '';
        $logo = get_option( 'site_logo' );

        if($logo && isset($logo['url'])){
            $css = 'h1 a{ background-image: url(' . esc_url($logo['url']) . ') !important; }';
        }
        if($css){
            echo '<style type="text/css">' . $css . '</style>';
        }
    }


    public function addCF7FormClass($class)
    {
        return $class;
    }


    /**
     * Filter form generated by Form7 plugin
     *
     * @param $content
     * @return mixed
     */
    public function stripBr($content)
    {
        $content = str_replace(array('<br>', '<br/>', '<br />', '<label>', '</label>'), '', $content);
        $rand = rand(1, 1000);

        preg_match_all('/<input type="checkbox" [^>]+>/ui', $content, $matches);
        if ($matches) {
            if(isset($matches[0])){
                foreach($matches[0] as $k => $checkbox){
                    $checkbox_with_id = str_replace('<input type="checkbox"', '<input id="newsletter-subscription' . $rand . '" type="checkbox"', $checkbox);
                    $content          = str_replace($checkbox, $checkbox_with_id . '<label for="newsletter-subscription' . $rand . '"></label>' , $content);
                }
            }
        }
        return $content;
    }


    /**
     * Register required plugin
     */
    public function registerRequiredPlugins()
    {
        /**
         * Array of plugin arrays. Required keys are name and slug.
         * If the source is NOT from the .org repo, then source is also required.
         */
        $plugins = array(
            // This is an example of how to include a plugin pre-packaged with a theme.
            array(
                'name' => 'Shortcodes Ultimate', // The plugin name.
                'slug' => 'shortcodes-ultimate', // The plugin slug (typically the folder name).
                'required' => true, // If false, the plugin is only 'recommended' instead of required.
                'version' => '4.9.8.1', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
            ),
            // Handyman addon for Shortcodes Ultimate
            array(
                'name' => 'TL Handyman addons for Shortcodes Ultimate', // The plugin name.
                'slug' => 'handyman-shortcodes-ultimate-addon', // The plugin slug (typically the folder name).
                'source' => get_stylesheet_directory() . '/prepacked-plugins/handyman-shortcodes-ultimate-addon.zip', // The plugin source.
                'required' => true, // If false, the plugin is only 'recommended' instead of required.
                'version' => '1.0.9', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
                'force_activation' => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
                'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
                'external_url' => '', // If set, overrides default API URL and points to an external URL.
            ),
            // Contact form 7
            array(
                'name' => 'Contact Form 7', // The plugin name.
                'slug' => 'contact-form-7', // The plugin slug (typically the folder name).
                'source' => get_stylesheet_directory() . '/prepacked-plugins/contact-form-7.4.2.2.zip', // The plugin source.
                'required' => true, // If false, the plugin is only 'recommended' instead of required.
                'version' => '4.2.2', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
                'force_activation' => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
                'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
                'external_url' => '', // If set, overrides default API URL and points to an external URL.
            ),
            // Wordpress Importer
            array(
                'name' => 'Wordpress Importer', // The plugin name.
                'slug' => 'wordpress-importer', // The plugin slug (typically the folder name).
                'source' => get_stylesheet_directory() . '/prepacked-plugins/wordpress-importer.0.6.1.zip', // The plugin source.
                'required' => false, // If false, the plugin is only 'recommended' instead of required.
                'version' => '0.6.1', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
                'force_activation' => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
                'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
                'external_url' => '', // If set, overrides default API URL and points to an external URL.
            ),
            // Layers Insert staff
            array(
                'name' => 'TL Layers Handyman Plugin', // The plugin name.
                'slug' => 'layers-insert-staff', // The plugin slug (typically the folder name).
                'source' => get_stylesheet_directory() . '/prepacked-plugins/layers-insert-staff.zip', // The plugin source.
                'required' => true, // If false, the plugin is only 'recommended' instead of required.
                'version' => '1.4.4', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
                'force_activation' => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
                'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
                'external_url' => '', // If set, overrides default API URL and points to an external URL.
            ),
            // Jetpack
            array(
                'name' => 'Jetpack', // The plugin name.
                'slug' => 'jetpack', // The plugin slug (typically the folder name).
                'required' => false, // If false, the plugin is only 'recommended' instead of required.
                'version' => '3.6.1', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
            )
        );


        /**
         * Array of configuration settings. Amend each line as needed.
         * If you want the default strings to be available under your own theme domain,
         * leave the strings uncommented.
         * Some of the strings are added into a sprintf, so see the comments at the
         * end of each line for what each argument will be.
         */
        $config = array(
            'default_path' => '',                      // Default absolute path to pre-packaged plugins.
            'menu' => 'tgmpa-install-plugins', // Menu slug.
            'has_notices' => true,                    // Show admin notices or not.
            'dismissable' => true,                    // If false, a user cannot dismiss the nag message.
            'dismiss_msg' => '',                      // If 'dismissable' is false, this message will be output at top of nag.
            'is_automatic' => false,                   // Automatically activate plugins after installation or not.
            'message' => '',                      // Message to output right before the plugins table.
            'strings' => array(
                'page_title' => __('Install Required Plugins', 'tgmpa'),
                'menu_title' => __('Install Plugins', 'tgmpa'),
                'installing' => __('Installing Plugin: %s', 'tgmpa'), // %s = plugin name.
                'oops' => __('Something went wrong with the plugin API.', 'tgmpa'),
                'notice_can_install_required' => _n_noop('This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.'), // %1$s = plugin name(s).
                'notice_can_install_recommended' => _n_noop('This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.'), // %1$s = plugin name(s).
                'notice_cannot_install' => _n_noop('Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.'), // %1$s = plugin name(s).
                'notice_can_activate_required' => _n_noop('The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.'), // %1$s = plugin name(s).
                'notice_can_activate_recommended' => _n_noop('The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.'), // %1$s = plugin name(s).
                'notice_cannot_activate' => _n_noop('Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.'), // %1$s = plugin name(s).
                'notice_ask_to_update' => _n_noop('The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.'), // %1$s = plugin name(s).
                'notice_cannot_update' => _n_noop('Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.'), // %1$s = plugin name(s).
                'install_link' => _n_noop('Begin installing plugin', 'Begin installing plugins'),
                'activate_link' => _n_noop('Begin activating plugin', 'Begin activating plugins'),
                'return' => __('Return to Required Plugins Installer', 'tgmpa'),
                'plugin_activated' => __('Plugin activated successfully.', 'tgmpa'),
                'complete' => __('All plugins installed and activated successfully. %s', 'tgmpa'), // %s = dashboard link.
                'nag_type' => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
            )
        );
        \tgmpa($plugins, $config);
    }
}