<?php
require_once 'class.abstract-post-type.php';
/**
 * Class TL_Testimonials_Post_Type
 */
if (!class_exists('TL_Testimonials_Post_Type')) {
    class TL_Testimonials_Post_Type extends TL_Abstract_Post_Type
    {

        public function __construct()
        {
            parent::__construct(
                array(
                    'post_type_name' => 'Testimonials',
                    'singular' => 'Testimonial',
                    'plural' => 'Testimonials',
                    'slug' => 'tl_testimonial'
                ),
                array(
                    'description' => __('User testimonials', $this->textdomain),
                    'public' => true,
                    'exclude_from_search' => false,
                    'publicly_queryable' => true,
                    'show_ui' => true,
                    'menu_position' => 20,
                    'capability_type' => 'post',
                    'hierarchical' => false,
                    'supports' => array('title', 'editor'),
                    'can_export' => true,
                    'has_archive' => false
                )
            );

            // define the columns to appear on the admin edit screen
            $this->columns(array(
                'cb'                 => '<input type="checkbox" />',
                'title'              => __('Name'      , TL_INSERT_STAFF_SLUG),
                'tl_testimonial'     => __('Testimonial', TL_INSERT_STAFF_SLUG),
                'date'               => __('Date'       , TL_INSERT_STAFF_SLUG),
            ));

            // populate testimonial column
            $this->populateColumn('tl_testimonial', function($column, $post)
            {
                tl_get_abstract(strip_shortcodes($post->post_content), 5, true);
            });


            // Alter placeholder value on add new post item screen
            add_filter('enter_title_here', array($this, 'changeDefaultTitle'));

            // Add Template locations
            //add_filter('layers_template_locations', [$this, 'addTemplateLocations']);
        }


        /**
         *
         * @param $title
         * @return string|void
         */
        public function changeDefaultTitle($title)
        {
            $screen = get_current_screen();
            if ($this->slug == $screen->post_type) {
                $title = __('Enter Person\'s full name', $this->textdomain);
            }
            return $title;
        }


        /**
         * Add Template Locations
         *
         * @param $template_locations
         * @return array
         */
        public function addTemplateLocations($template_locations)
        {
            $template_locations[] = TL_INSERT_STAFF_DIR . 'post-types/templates';
            return $template_locations;
        }
    }
}
// Register CPT
new TL_Testimonials_Post_Type();