<?php
if (!class_exists('TL_Layers_Abstract_Widget')) { return; }

if (!class_exists('TL_Layers_Slider_Widget')) {
    class TL_Layers_Slider_Widget extends TL_Layers_Abstract_Widget
    {
        /**
         *  Widget construction
         */
        public function __construct()
        {
            /**
             * Widget variables
             *
             * @param    string $widget_title Widget title
             * @param    string $widget_id Widget slug for use as an ID/classname
             * @param    string $post_type (optional) Post type for use in widget options
             * @param    string $taxonomy (optional) Taxonomy slug for use as an ID/classname
             * @param    array $checkboxes (optional) Array of checkbox names to be saved in this widget. Don't forget these please!
             */
            $this->widget_title = __('Layer 5 Slider', TL_INSERT_STAFF_SLUG);
            $this->widget_id = 'tl_layerslider';
            $this->checkboxes = array();

            /* Widget settings. */
            $widget_ops = array('classname' => 'obox-layers-' . $this->widget_id . '-widget', 'description' => __('This widget is used to display your ', 'layerswp') . $this->widget_title . '.');

            /* Widget control settings. */
            $control_ops = array('width' => LAYERS_WIDGET_WIDTH_SMALL,
                'height' => NULL,
                'id_base' => LAYERS_THEME_SLUG . '-widget-' . $this->widget_id);

            /* Create the widget. */
            parent::__construct(LAYERS_THEME_SLUG . '-widget-' . $this->widget_id, $this->widget_title, $widget_ops, $control_ops);

            /* Setup Widget Defaults */
            $this->defaults = array(
                'title' => __('SLIDER TITLE', TL_INSERT_STAFF_SLUG),
            );

            /* Add filters */
            $this->_addFilters();


            $this->get_theme_colors();
        }


        /**
         * @param array $instance
         * @return string|void
         */
        public function form($instance)
        {
            // $instance Defaults
            $instance_defaults = $this->defaults;

            // If we have information in this widget, then ignore the defaults
            if (!empty($instance)) $instance_defaults = array();

            // Parse $instance
            $widget = wp_parse_args($instance, $instance_defaults);

            $design_bar_components = apply_filters('layers_' . $this->widget_id . '_widget_design_bar_components', array(
                'display' => array(
                    'icon-css' => 'icon-display',
                    'label' => __('Display', 'layerswp'),
                    'elements' => array()
                ),
                'background'
            ));

            if(TL_INSERT_STAFF_WIDGET_FORM_MIN) ob_start('tl_sanitize_output');

            $this->design_bar(
                'side', // CSS Class Name
                array(
                    'name' => $this->get_field_name('design'),
                    'id' => $this->get_field_id('design'),
                ), // Widget Object
                $widget, // Widget Values
                $design_bar_components // Standard Components
            );
            ?>
            <div class="layers-container-large" >
                <?php $this->form_elements()->header(array(
                        'title'      => __('Header', TL_INSERT_STAFF_SLUG),
                        'icon_class' => 'post'
                )); ?>
                <section class="layers-accordion-section layers-content">
                    <div class="layers-row layers-push-bottom">
                        <p class="layers-form-item">
                            <?php echo $this->form_elements()->input(
                                                array(
                                                    'type' => 'text',
                                                    'name' => $this->get_field_name('title'),
                                                    'id'   => $this->get_field_id('title'),
                                                    'placeholder' => __('Heading Text', TL_INSERT_STAFF_SLUG),
                                                    'value'       => (isset($widget['title'])) ? $widget['title'] : NULL,
                                                    'class'       => 'layers-text layers-large',

                                                )
                                            ); ?>
                            <small class="layers-small-note"><?php _e('Header Title. Leave it blank to remove heading.', TL_INSERT_STAFF_SLUG)?></small>
                        </p>
                    </div>
                </section>
            </div>
        <?php
            if(TL_INSERT_STAFF_WIDGET_FORM_MIN) ob_end_flush();
        }


        /**
         * @param array $args
         * @param array $instance
         */
        public function widget($args, $instance)
        {
            global $widget, $widget_id;

            // Turn $args array into variables.
            extract($args);

            // $instance Defaults
            $instance_defaults = $this->defaults;

            // If we have information in this widget, then ignore the defaults
            if (!empty($instance)) $instance_defaults = array();

            // Parse $instance
            $widget = wp_parse_args($instance, $instance_defaults);

            if($this->colors){
                // Set inline CSS styles
                layers_inline_styles(array('selectors' => array('.header-site'),
                    'css'       => array('background-color' => $this->colors->get('_secondary') .' !important')));
            }


            // Background image
            if($this->check_and_return($widget, 'design', 'background', 'image')){
                layers_inline_styles('#' . $widget_id, 'background', array('background' => $widget['design']['background']));
            }

            echo $this->custom_anchor( $widget );
        }



        /**
         *
         */
        protected function _addFilters()
        {
            add_filter('tl/layers/background_component/' . $this->widget_id . '/args', array($this, 'customizeBackgroundComponent'), 10, 4);
        }


        /**
         * @param $args
         * @param $position
         * @param $widget
         * @param $values
         * @return mixed
         */
        public function customizeBackgroundComponent($args, $position, $widget, $values)
        {
            if($position == 'side'){
                unset($args['elements']['background-darken']);
                unset($args['elements']['background-color']);
            }
            return $args;
        }

    }

    // Add our function to the widgets_init hook.
   // register_widget("TL_Layers_Slider_Widget");
}