<?php

/**
 * Class WP_Widget_Tag_Cloud
 */
class TL_Widget_Tag extends WP_Widget
{


    public function __construct()
    {
        $widget_ops = array('description' => __("List of available tags"));
        parent::__construct('tl_tag', __('Tag List'), $widget_ops);

        add_filter('tl_wp_tag_cloud', array($this, 'addClasses'), 10, 2);

    }


    public function addClasses($tags, $args)
    {
        $tags = preg_replace('/class=\'[a-z0-9\-]+\'/i', 'class="hvr-float"', $tags);
        return $tags;
    }

    public function widget($args, $instance)
    {
        $current_taxonomy = $this->_get_current_taxonomy($instance);
        if (!empty($instance['title'])) {
            $title = $instance['title'];
        } else {
            if ('post_tag' == $current_taxonomy) {
                $title = __('Tags');
            } else {
                $tax = get_taxonomy($current_taxonomy);
                $title = $tax->labels->name;
            }
        }

        /** This filter is documented in wp-includes/default-widgets.php */
        $title = apply_filters('widget_title', $title, $instance, $this->id_base);

        echo $args['before_widget'];
        if ($title) {
            echo $args['before_title'] . esc_html($title) . $args['after_title'];
        }
        echo '<div class="tag-list">';

        /**
         * Filter the taxonomy used in the Tag Cloud widget.
         *
         * @since 2.8.0
         * @since 3.0.0 Added taxonomy drop-down.
         *
         * @see wp_tag_cloud()
         *
         * @param array $current_taxonomy The taxonomy to use in the tag cloud. Default 'tags'.
         */
        wp_tag_cloud(apply_filters('widget_tag_cloud_args', array(
            'taxonomy' => $current_taxonomy,
            'smallest' => 1.4, 'largest' => 1.4, 'unit' => 'rem'
        )));

        echo "</div>\n";
        echo $args['after_widget'];
    }


    public function update($new_instance, $old_instance)
    {
        $instance = array();
        $instance['title'] = strip_tags(stripslashes($new_instance['title']));
        $instance['taxonomy'] = stripslashes($new_instance['taxonomy']);
        return $instance;
    }


    public function form($instance)
    {
        $current_taxonomy = $this->_get_current_taxonomy($instance);
        ?>
        <p><label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e(__('Title:', TL_INSERT_STAFF_SLUG)); ?></label>
            <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>"
                   value="<?php if (isset ($instance['title'])) {
                       echo esc_attr($instance['title']);
                   } ?>"/></p>
        <p><label for="<?php echo esc_attr($this->get_field_id('taxonomy')); ?>"><?php esc_html_e('Taxonomy:', TL_INSERT_STAFF_SLUG); ?></label>
        <select class="widefat" id="<?php echo esc_attr($this->get_field_id('taxonomy')); ?>" name="<?php echo esc_attr($this->get_field_name('taxonomy')); ?>">
            <?php foreach (get_taxonomies() as $taxonomy) :
                $tax = get_taxonomy($taxonomy);
                if (!$tax->show_tagcloud || empty($tax->labels->name))
                    continue;
                ?>
                <option value="<?php echo esc_attr($taxonomy) ?>" <?php selected($taxonomy, $current_taxonomy) ?>><?php echo esc_html($tax->labels->name); ?></option>
            <?php endforeach; ?>
        </select></p><?php
    }


    public function _get_current_taxonomy($instance)
    {
        if (!empty($instance['taxonomy']) && taxonomy_exists($instance['taxonomy']))
            return $instance['taxonomy'];

        return 'post_tag';
    }
}

register_widget('TL_Widget_Tag');